==> duiba-galaxy-sdk-0.0.1-20221111.015201-40-sources.jar: cn/com/duiba/galaxy/sdk/apiextra/ConsumerApi.java <==
package cn.com.duiba.galaxy.sdk.apiextra;

import cn.com.duiba.galaxy.sdk.Api;
import cn.com.duiba.galaxy.sdk.datas.ConsumerData;
import cn.com.duiba.galaxy.sdk.datas.ConsumerExtra;
import cn.com.duiba.galaxy.sdk.exception.BizRuntimeException;

import java.util.List;

public interface ConsumerApi extends Api {

    /**
     * 批量获取用户extra信息
     *
     * @param ids consumer ids
     * @return list
     * @throws BizRuntimeException exception
     */
    List<ConsumerExtra> listConsumerExtraByConsumerIds(List<Long> ids) throws BizRuntimeException;

    /**
     * 批量获取用户信息
     *
     * @param ids consumer ids
     * @return list
     * @throws BizRuntimeException exception
     */
    List<ConsumerData> listConsumerByConsumerIds(List<Long> ids) throws BizRuntimeException;

    /**
     * 当前用户是否为新用户
     * true 新用户  false 老用户
     *
     * @param consumerId consumerId
     * @return boolean
     * @throws BizRuntimeException exception
     */
    boolean isNewUser(Long consumerId) throws BizRuntimeException;

    /**
     * 通过开发者用户id获取用户信息
     *
     * @param appId         appId
     * @param partnerUserId 开发者用户id
     * @return consumer
     * @throws BizRuntimeException exception
     */
    ConsumerData findByAppAndPartnerUserId(Long appId, String partnerUserId);

    /**
     * 通过开发者用户id获取用户信息
     *
     * @param appId          appId
     * @param partnerUserIds 开发者用户id集合
     * @return consumer
     * @throws BizRuntimeException exception
     */
    List<ConsumerData> findByAppAndPartnerUserIds(Long appId, List<String> partnerUserIds);

    /**
     * @description 通过key 查询consumerExtra表json里的扩展字段
     * @author liheping
     * @date 2020/12/3
     */
    String findConsumerExtra(Long consumerId, String key);

}

==> duiba-galaxy-sdk-0.0.3-sources.jar: cn/com/duiba/galaxy/sdk/apiextra/ConsumerApi.java <==
package cn.com.duiba.galaxy.sdk.apiextra;

import cn.com.duiba.galaxy.sdk.Api;
import cn.com.duiba.galaxy.sdk.datas.ConsumerData;
import cn.com.duiba.galaxy.sdk.datas.ConsumerExtra;
import cn.com.duiba.galaxy.sdk.exception.BizRuntimeException;

import java.util.List;

public interface ConsumerApi extends Api {

    /**
     * 批量获取用户extra信息
     *
     * @param ids consumer ids
     * @return list
     * @throws BizRuntimeException exception
     */
    List<ConsumerExtra> listConsumerExtraByConsumerIds(List<Long> ids) throws BizRuntimeException;

    /**
     * 批量获取用户信息
     *
     * @param ids consumer ids
     * @return list
     * @throws BizRuntimeException exception
     */
    List<ConsumerData> listConsumerByConsumerIds(List<Long> ids) throws BizRuntimeException;

    /**
     * 通过用户id查询用户信息
     *
     * @param id id
     * @return {@link ConsumerData}
     * @throws BizRuntimeException 业务运行时异常
     */
    ConsumerData getConsumerByConsumerId(Long id) throws BizRuntimeException;

    /**
     * 当前用户是否为新用户
     * true 新用户  false 老用户
     *
     * @param consumerId consumerId
     * @return boolean
     * @throws BizRuntimeException exception
     */
    boolean isNewUser(Long consumerId) throws BizRuntimeException;

    /**
     * 通过开发者用户id获取用户信息
     *
     * @param appId         appId
     * @param partnerUserId 开发者用户id
     * @return consumer
     * @throws BizRuntimeException exception
     */
    ConsumerData findByAppAndPartnerUserId(Long appId, String partnerUserId);

    /**
     * 通过开发者用户id获取用户信息
     *
     * @param appId          appId
     * @param partnerUserIds 开发者用户id集合
     * @return consumer
     * @throws BizRuntimeException exception
     */
    List<ConsumerData> findByAppAndPartnerUserIds(Long appId, List<String> partnerUserIds);

    /**
     * @description 通过key 查询consumerExtra表json里的扩展字段
     * @author liheping
     * @date 2020/12/3
     */
    String findConsumerExtra(Long consumerId, String key);

}
